@@ -22,19 +22,19 @@ pub struct VMConfig {
 /// Describes limits for VM and Runtime.
 /// TODO #4139: consider switching to strongly-typed wrappers instead of raw quantities
 #[derive(Debug, Serialize, Deserialize, Clone, Hash, PartialEq, Eq)]
+#[serde(default)]
 pub struct VMLimitConfig {
     /// Max amount of gas that can be used, excluding gas attached to promises.
     pub max_gas_burnt: Gas,
+    /// Max burnt gas per view method.
+    /// TODO #4719: remove this field because it does not affect the protocol
+    pub max_gas_burnt_view: Gas,
 
     /// How tall the stack is allowed to grow?
     ///
     /// See <https://wiki.parity.io/WebAssembly-StackHeight> to find out
     /// how the stack frame cost is calculated.
     pub max_stack_height: u32,
-    /// Whether a legacy version of stack limiting should be used, see
-    /// [`StackLimiterVersion`].
-    #[serde(default = "StackLimiterVersion::v0")]
-    pub stack_limiter_version: StackLimiterVersion,
 
     /// The initial number of memory pages.
     /// NOTE: It's not a limiter itself, but it's a value we use for initial_memory_pages.
@@ -81,77 +81,20 @@ pub struct VMLimitConfig {
     pub max_promises_per_function_call_action: u64,
     /// Max number of input data dependencies
     pub max_number_input_data_dependencies: u64,
-    /// If present, stores max number of functions in one contract
-    #[serde(skip_serializing_if = "Option::is_none")]
-    pub max_functions_number_per_contract: Option<u64>,
 }
 
-/// Our original code for limiting WASM stack was buggy. We fixed that, but we
-/// still have to use old (`V0`) limiter for old protocol versions.
-///
-/// This struct here exists to enforce that the value in the config is either
-/// `0` or `1`. We could have used a `bool` instead, but there's a chance that
-/// our current impl isn't perfect either and would need further tweaks in the
-/// future.
-#[derive(Debug, Clone, Copy, Hash, PartialEq, Eq)]
-pub enum StackLimiterVersion {
-    /// Old, buggy version, don't use it unless specifically to support old protocol version.
-    V0,
-    /// What we use in today's protocol.
-    V1,
-}
-
-impl StackLimiterVersion {
-    fn v0() -> StackLimiterVersion {
-        StackLimiterVersion::V0
-    }
-    fn repr(self) -> u32 {
-        match self {
-            StackLimiterVersion::V0 => 0,
-            StackLimiterVersion::V1 => 1,
+impl Default for VMConfig {
+    fn default() -> VMConfig {
+        VMConfig {
+            ext_costs: ExtCostsConfig::default(),
+            grow_mem_cost: 1,
+            regular_op_cost: (SAFETY_MULTIPLIER as u32) * 1285457,
+            limit_config: VMLimitConfig::default(),
         }
     }
-    fn from_repr(repr: u32) -> Option<StackLimiterVersion> {
-        let res = match repr {
-            0 => StackLimiterVersion::V0,
-            1 => StackLimiterVersion::V1,
-            _ => return None,
-        };
-        Some(res)
-    }
-}
-
-impl Serialize for StackLimiterVersion {
-    fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
-    where
-        S: serde::Serializer,
-    {
-        self.repr().serialize(serializer)
-    }
-}
-
-impl<'de> Deserialize<'de> for StackLimiterVersion {
-    fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
-    where
-        D: serde::Deserializer<'de>,
-    {
-        u32::deserialize(deserializer).and_then(|repr| {
-            StackLimiterVersion::from_repr(repr)
-                .ok_or_else(|| serde::de::Error::custom("invalid stack_limiter_version"))
-        })
-    }
 }
 
 impl VMConfig {
-    pub fn test() -> VMConfig {
-        VMConfig {
-            ext_costs: ExtCostsConfig::test(),
-            grow_mem_cost: 1,
-            regular_op_cost: (SAFETY_MULTIPLIER as u32) * 1285457,
-            limit_config: VMLimitConfig::test(),
-        }
-    }
-
     /// Computes non-cryptographically-proof hash. The computation is fast but not cryptographically
     /// secure.
     pub fn non_crypto_hash(&self) -> u64 {
@@ -166,20 +109,24 @@ impl VMConfig {
             grow_mem_cost: 0,
             regular_op_cost: 0,
             // We shouldn't have any costs in the limit config.
-            limit_config: VMLimitConfig { max_gas_burnt: u64::MAX, ..VMLimitConfig::test() },
+            limit_config: VMLimitConfig {
+                max_gas_burnt: u64::MAX,
+                max_gas_burnt_view: u64::MAX,
+                ..Default::default()
+            },
         }
     }
 }
 
-impl VMLimitConfig {
-    pub fn test() -> Self {
+impl Default for VMLimitConfig {
+    fn default() -> Self {
         Self {
             max_gas_burnt: 2 * 10u64.pow(14), // with 10**15 block gas limit this will allow 5 calls.
+            max_gas_burnt_view: 2 * 10u64.pow(14), // same as `max_gas_burnt` for now
 
             // NOTE: Stack height has to be 16K, otherwise Wasmer produces non-deterministic results.
             // For experimentation try `test_stack_overflow`.
-            max_stack_height: 16 * 1024, // 16Kib of stack.
-            stack_limiter_version: StackLimiterVersion::V1,
+            max_stack_height: 16 * 1024,        // 16Kib of stack.
             initial_memory_pages: 2u32.pow(10), // 64Mib of memory.
             max_memory_pages: 2u32.pow(11),     // 128Mib of memory.
 
@@ -215,7 +162,6 @@ impl VMLimitConfig {
             max_promises_per_function_call_action: 1024,
             // Unlikely to hit it for normal development.
             max_number_input_data_dependencies: 128,
-            max_functions_number_per_contract: None,
         }
     }
 }
@@ -228,6 +174,7 @@ pub struct ViewConfig {
 }
 
 #[derive(Debug, Serialize, Deserialize, Clone, Hash, PartialEq, Eq)]
+#[serde(default)]
 pub struct ExtCostsConfig {
     /// Base cost for calling a host function.
     pub base: Gas,
@@ -396,8 +343,9 @@ pub struct ExtCostsConfig {
 // have certain reserve for further gas price variation.
 const SAFETY_MULTIPLIER: u64 = 3;
 
-impl ExtCostsConfig {
-    pub fn test() -> ExtCostsConfig {
+/// TODO #4649: remove default implementation when LowerEcrecoverBaseCost will be released
+impl Default for ExtCostsConfig {
+    fn default() -> ExtCostsConfig {
         ExtCostsConfig {
             base: SAFETY_MULTIPLIER * 88256037,
             contract_compile_base: SAFETY_MULTIPLIER * 11815321,
@@ -468,7 +416,9 @@ impl ExtCostsConfig {
             alt_bn128_g1_sum_byte: SAFETY_MULTIPLIER * 25406181,
         }
     }
+}
 
+impl ExtCostsConfig {
     fn free() -> ExtCostsConfig {
         ExtCostsConfig {
             base: 0,
